==> c2nload-1.0.tar.gz: c2nload-1.0/encode.h <==
/**
 * @file encode.h
 * C2N pulse stream encoder interface
 * @author Marko Mkel <msmakela@nic.funet.fi>
 */

/* Copyright  2001,2002 Marko Mkel.

   This file is part of C2NLOAD, a program for loading files to
   Commodore 8-bit computes via the C2N232 device.

   C2NLOAD is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   C2NLOAD is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   The GNU General Public License is often shipped with GNU software, and
   is generally kept in a file called COPYING or LICENSE.  If you do not
   have a copy of the license, write to the Free Software Foundation,
   59 Temple Place, Suite 330, Boston, MA 02111 USA. */

/** Pulse stream encoder
 * @param data	the 194-byte data to be encoded
 * @param begin	number of initial synchronization pulses
 * @param intra	number of intra-block synchronization pulses
 * @param plus4	flag: encode in Commodore 264 series format
 * @param name	file name to be loaded
 * @param start	start address of the actual data
 * @param len	length of the actual data
 * @param sys	sys address (0 if none)
 */
void
encode (const unsigned char* data,
	unsigned begin, unsigned intra, unsigned plus4,
	const char* name, unsigned start, unsigned len, unsigned sys);

==> c2nload-1.0.2.tar.gz: c2nload-1.0.2/encode.h <==
/**
 * @file encode.h
 * C2N pulse stream encoder interface
 * @author Marko Mkel <msmakela@nic.funet.fi>
 */

/* Copyright  2001,2002 Marko Mkel.

   This file is part of C2NLOAD, a program for loading files to
   Commodore 8-bit computers via the C2N232 device.

   C2NLOAD is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   C2NLOAD is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   The GNU General Public License is often shipped with GNU software, and
   is generally kept in a file called COPYING or LICENSE.  If you do not
   have a copy of the license, write to the Free Software Foundation,
   59 Temple Place, Suite 330, Boston, MA 02111 USA. */

/** Pulse stream encoder
 * @param data	the 194-byte data to be encoded
 * @param begin	number of initial synchronization pulses
 * @param intra	number of intra-block synchronization pulses
 * @param plus4	flag: encode in Commodore 264 series format
 * @param name	file name to be loaded
 * @param start	start address of the actual data
 * @param len	length of the actual data
 * @param sys	sys address (0 if none)
 */
void
encode (const unsigned char* data,
	unsigned begin, unsigned intra, unsigned plus4,
	const char* name, unsigned start, unsigned len, unsigned sys);
